function [] = printadmresults(digesterin, digesterout, par, ACTIVATE)
% printadmresults.m
% Prints the inputs and outputs of the BSM2 ADM1 model
% digesterin is the input in ADM1 terminology + extra states, 33 variables
% digesterin[1] : Ssu = monosacharides (kg COD/m3)
% digesterin[2] : Saa = amino acids (kg COD/m3)
% digesterin[3] : Sfa = long chain fatty acids (LCFA) (kg COD/m3)
% digesterin[4] : Sva = total valerate (kg COD/m3)
% digesterin[5] : Sbu = total butyrate (kg COD/m3)
% digesterin[6] : Spro = total propionate (kg COD/m3)
% digesterin[7] : Sac = total acetate (kg COD/m3)
% digesterin[8] : Sh2 = hydrogen gas (kg COD/m3)
% digesterin[9] : Sch4 = methane gas (kg COD/m3)
% digesterin[10] : Sic = inorganic carbon (kmole C/m3)
% digesterin[11] : Sin = inorganic nitrogen (kmole N/m3)
% digesterin[12] : Si = soluble inerts (kg COD/m3)
% digesterin[13] : Xc = composites (kg COD/m3)
% digesterin[14] : Xch = carbohydrates (kg COD/m3)
% digesterin[15] : Xpr = proteins (kg COD/m3)
% digesterin[16] : Xli = lipids (kg COD/m3)
% digesterin[17] : Xsu = sugar degraders (kg COD/m3)
% digesterin[18] : Xaa = amino acid degraders (kg COD/m3)
% digesterin[19] : Xfa = LCFA degraders (kg COD/m3)
% digesterin[20] : Xc4 = valerate and butyrate degraders (kg COD/m3)
% digesterin[21] : Xpro = propionate degraders (kg COD/m3)
% digesterin[22] : Xac = acetate degraders (kg COD/m3)
% digesterin[23] : Xh2 = hydrogen degraders (kg COD/m3)
% digesterin[24] : Xi = particulate inerts (kg COD/m3)
% digesterin[25] : scat+ = cations (metallic ions, strong base) (kmole/m3)
% digesterin[26] : san- = anions (metallic ions, strong acid) (kmole/m3)
% digesterin[27] : flow rate (m3/d)
% digesterin[28] : temperature (deg C)
% digesterin[29:33] : dummy states for future use
%
% digesterout is the output in ADM1 terminology + extra states, 50 variables
% digesterout[1] : Ssu = monosacharides (kg COD/m3)
% digesterout[2] : Saa = amino acids (kg COD/m3)
% digesterout[3] : Sfa = long chain fatty acids (LCFA) (kg COD/m3)
% digesterout[4] : Sva = total valerate (kg COD/m3)
% digesterout[5] : Sbu = total butyrate (kg COD/m3)
% digesterout[6] : Spro = total propionate (kg COD/m3)
% digesterout[7] : Sac = total acetate (kg COD/m3)
% digesterout[8] : Sh2 = hydrogen gas (kg COD/m3)
% digesterout[9] : Sch4 = methane gas (kg COD/m3)
% digesterout[10] : Sic = inorganic carbon (kmole C/m3)
% digesterout[11] : Sout = inorganic nitrogen (kmole N/m3)
% digesterout[12] : Si = soluble inerts (kg COD/m3)
% digesterout[13] : Xc = composites (kg COD/m3)
% digesterout[14] : Xch = carbohydrates (kg COD/m3)
% digesterout[15] : Xpr = proteins (kg COD/m3)
% digesterout[16] : Xli = lipids (kg COD/m3)
% digesterout[17] : Xsu = sugar degraders (kg COD/m3)
% digesterout[18] : Xaa = amino acid degraders (kg COD/m3)
% digesterout[19] : Xfa = LCFA degraders (kg COD/m3)
% digesterout[20] : Xc4 = valerate and butyrate degraders (kg COD/m3)
% digesterout[21] : Xpro = propionate degraders (kg COD/m3)
% digesterout[22] : Xac = acetate degraders (kg COD/m3)
% digesterout[23] : Xh2 = hydrogen degraders (kg COD/m3)
% digesterout[24] : Xi = particulate inerts (kg COD/m3)
% digesterout[25] : scat+ = cations (metallic ions, strong base) (kmole/m3)
% digesterout[26] : san- = anions (metallic ions, strong acid) (kmole/m3)
% digesterout[27] : flow rate (m3/d)
% digesterout[28] : temperature (deg C)
% digesterout[29:33] : dummy states for future use
% digesterout[34] : pH = pH within AD system
% digesterout[35] : S_H+ = protons (kmole/m3)
% digesterout[36] : Sva- = valerate (kg COD/m3)
% digesterout[37] : Sbu- = butyrate (kg COD/m3)
% digesterout[38] : Spro- = propionate (kg COD/m3)
% digesterout[39] : Sac- = acetate (kg COD/m3)
% digesterout[40] : Shco3- = bicarbonate (kmole C/m3)
% digesterout[41] : Sco2 = carbon dioxide (kmole C/m3)
% digesterout[42] : Snh3 = ammonia (kmole N/m3)
% digesterout[43] : Snh4+ = ammonium (kmole N/m3)
% digesterout[44] : Sgas,h2 = hydrogen concentration in gas phase (kg COD/m3)
% digesterout[45] : Sgas,ch4 = methane concentration in gas phase (kg COD/m3)
% digesterout[46] : Sgas,co2 = carbon dioxide concentration in gas phase (kmole C/m3)
% digesterout[47] : pgas,h2 = partial pressure of hydrogen gas (bar)
% digesterout[48] : pgas,ch4 = partial pressure of methane gas (bar)
% digesterout[49] : pgas,co2 = partial pressure of carbon dioxide gas (bar)
% digesterout[50] : pgas,total = total head space pressure (H2+CO2+CH4+H2O) (bar)
% digesterout[51] : qgas = gas flow rate normalised to atmospheric pressure (m3/d)

R = par(78);
T_op = par(80);
P_atm = par(94);

disp(' ')
disp('ADM1 influent (post ASM2ADM interface)')
disp('*************************************')
disp(['   Ssu = monosacharides (kg COD/m3) = ', num2str(digesterin(end,1))]);
disp(['   Saa = amino acids (kg COD/m3) = ', num2str(digesterin(end,2))]);
disp(['   Sfa = long chain fatty acids (LCFA) (kg COD/m3) = ', num2str(digesterin(end,3))]);
disp(['   Sva = total valerate (kg COD/m3) = ', num2str(digesterin(end,4))]);
disp(['   Sbu = total butyrate (kg COD/m3) = ', num2str(digesterin(end,5))]);
disp(['   Spro = total propionate (kg COD/m3) = ', num2str(digesterin(end,6))]);
disp(['   Sac = total acetate (kg COD/m3) = ', num2str(digesterin(end,7))]);
disp(['   Sh2 = hydrogen gas (kg COD/m3) = ', num2str(digesterin(end,8))]);
disp(['   Sch4 = methane gas (kg COD/m3) = ', num2str(digesterin(end,9))]);
disp(['   Sic = inorganic carbon (kmole C/m3) = ', num2str(digesterin(end,10))]);
disp(['   Sin = inorganic nitrogen (kmole N/m3) = ', num2str(digesterin(end,11))]);
disp(['   Si = soluble inerts (kg COD/m3) = ', num2str(digesterin(end,12))]);
disp(['   Xc = composites (kg COD/m3) = ', num2str(digesterin(end,13))]);
disp(['   Xch = carbohydrates (kg COD/m3) = ', num2str(digesterin(end,14))]);
disp(['   Xpr = proteins (kg COD/m3) = ', num2str(digesterin(end,15))]);
disp(['   Xli = lipids (kg COD/m3) = ', num2str(digesterin(end,16))]);
disp(['   Xsu = sugar degraders (kg COD/m3) = ', num2str(digesterin(end,17))]);
disp(['   Xaa = amino acid degraders (kg COD/m3) = ', num2str(digesterin(end,18))]);
disp(['   Xfa = LCFA degraders (kg COD/m3) = ', num2str(digesterin(end,19))]);
disp(['   Xc4 = valerate and butyrate degraders (kg COD/m3) = ', num2str(digesterin(end,20))]);
disp(['   Xpro = propionate degraders (kg COD/m3) = ', num2str(digesterin(end,21))]);
disp(['   Xac = acetate degraders (kg COD/m3) = ', num2str(digesterin(end,22))]);
disp(['   Xh2 = hydrogen degraders (kg COD/m3) = ', num2str(digesterin(end,23))]);
disp(['   Xi = particulate inerts (kg COD/m3) = ', num2str(digesterin(end,24))]);
disp(['   Scat+ = cations (base) (kmole/m3) = ', num2str(digesterin(end,25))]);
disp(['   San- = anions (acid) (kmole/m3) = ', num2str(digesterin(end,26))]);
disp(['   Flow rate (m3/d) = ', num2str(digesterin(end,27))]);
disp(['   Temperature (degC) = ', num2str(digesterin(end,28))]);
if (ACTIVATE > 0.5)
disp(['   Dummy soluble state no 1 (g xxx/m3) = ', num2str(digesterin(end,29))]);
disp(['   Dummy soluble state no 2 (g xxx/m3) = ', num2str(digesterin(end,30))]);
disp(['   Dummy soluble state no 3 (g xxx/m3) = ', num2str(digesterin(end,31))]);
disp(['   Dummy particulate state no 1 (g xxx/m3) = ', num2str(digesterin(end,32))]);
disp(['   Dummy particulate state no 2 (g xxx/m3) = ', num2str(digesterin(end,33))]);
end;

disp(' ')
disp('ADM1 effluent (prior ADM2ASM interface)')
disp('***************************************')
disp(['   Ssu = monosacharides (kg COD/m3) = ', num2str(digesterout(end,1))]);
disp(['   Saa = amino acids (kg COD/m3) = ', num2str(digesterout(end,2))]);
disp(['   Sfa = long chain fatty acids (LCFA) (kg COD/m3) = ', num2str(digesterout(end,3))]);
disp(['   Sva = total valerate (kg COD/m3) = ', num2str(digesterout(end,4))]);
disp(['   Sbu = total butyrate (kg COD/m3) = ', num2str(digesterout(end,5))]);
disp(['   Spro = total propionate (kg COD/m3) = ', num2str(digesterout(end,6))]);
disp(['   Sac = total acetate (kg COD/m3) = ', num2str(digesterout(end,7))]);
disp(['   Sh2 = hydrogen gas (kg COD/m3) = ', num2str(digesterout(end,8))]);
disp(['   Sch4 = methane gas (kg COD/m3) = ', num2str(digesterout(end,9))]);
disp(['   Sic = inorganic carbon (kmole C/m3) = ', num2str(digesterout(end,10))]);
disp(['   Sin = inorganic nitrogen (kmole N/m3) = ', num2str(digesterout(end,11)), ' (= ', num2str(digesterout(end,11)*14), ' kg N/m3)']);
disp(['   Si = soluble inerts (kg COD/m3) = ', num2str(digesterout(end,12))]);
disp(['   Xc = composites (kg COD/m3) = ', num2str(digesterout(end,13))]);
disp(['   Xch = carbohydrates (kg COD/m3) = ', num2str(digesterout(end,14))]);
disp(['   Xpr = proteins (kg COD/m3) = ', num2str(digesterout(end,15))]);
disp(['   Xli = lipids (kg COD/m3) = ', num2str(digesterout(end,16))]);
disp(['   Xsu = sugar degraders (kg COD/m3) = ', num2str(digesterout(end,17))]);
disp(['   Xaa = amino acid degraders (kg COD/m3) = ', num2str(digesterout(end,18))]);
disp(['   Xfa = LCFA degraders (kg COD/m3) = ', num2str(digesterout(end,19))]);
disp(['   Xc4 = valerate and butyrate degraders (kg COD/m3) = ', num2str(digesterout(end,20))]);
disp(['   Xpro = propionate degraders (kg COD/m3) = ', num2str(digesterout(end,21))]);
disp(['   Xac = acetate degraders (kg COD/m3) = ', num2str(digesterout(end,22))]);
disp(['   Xh2 = hydrogen degraders (kg COD/m3) = ', num2str(digesterout(end,23))]);
disp(['   Xi = particulate inerts (kg COD/m3) = ', num2str(digesterout(end,24))]);
disp(['   Scat+ = cations (base) (kmole/m3) = ', num2str(digesterout(end,25))]);
disp(['   San- = anions (acid) (kmole/m3) = ', num2str(digesterout(end,26))]);
disp(['   Flow rate (m3/d) = ', num2str(digesterout(end,27))]);
disp(['   Temperature (degC) = ', num2str(digesterout(end,28))]);
if (ACTIVATE > 0.5)
disp(['   Dummy soluble state no 1 (g xxx/m3) = ', num2str(digesterout(end,29))]);
disp(['   Dummy soluble state no 2 (g xxx/m3) = ', num2str(digesterout(end,30))]);
disp(['   Dummy soluble state no 3 (g xxx/m3) = ', num2str(digesterout(end,31))]);
disp(['   Dummy particulate state no 1 (g xxx/m3) = ', num2str(digesterout(end,32))]);
disp(['   Dummy particulate state no 2 (g xxx/m3) = ', num2str(digesterout(end,33))]);
end;
disp(['   pH = pH within AD system = ', num2str(digesterout(end,34))]);
disp(['   S_H+ = protons (kmole/m3) = ', num2str(digesterout(end,35))]);
disp(['   Sva- = valerate (kg COD/m3) = ', num2str(digesterout(end,36))]);
disp(['   Sbu- = butyrate (kg COD/m3) = ', num2str(digesterout(end,37))]);
disp(['   Spro- = propionate (kg COD/m3) = ', num2str(digesterout(end,38))]);
disp(['   Sac- = acetate (kg COD/m3) = ', num2str(digesterout(end,39))]);
disp(['   Shco3- = bicarbonate (kmole C/m3) = ', num2str(digesterout(end,40))]);
disp(['   Sco2 = carbon dioxide (kmole C/m3) = ', num2str(digesterout(end,41))]);
disp(['   Snh3 = ammonia (kmole N/m3) = ', num2str(digesterout(end,42))]);
disp(['   Snh4+ = ammonium (kmole N/m3) = ', num2str(digesterout(end,43))]);
disp(['   Sgas,h2 = hydrogen concentration in gas phase (kg COD/m3) = ', num2str(digesterout(end,44))]);
disp(['   Sgas,ch4 = methane concentration in gas phase (kg COD/m3) = ', num2str(digesterout(end,45))]);
disp(['   Sgas,co2 = carbon dioxide concentration in gas phase (kmole C/m3) = ', num2str(digesterout(end,46))]);
disp(['   pgas,h2 = partial pressure of hydrogen gas (bar, true value i.e. not normalized) = ', num2str(digesterout(end,47))]);
disp(['   pgas,ch4 = partial pressure of methane gas (bar, true value i.e. not normalized) = ', num2str(digesterout(end,48))]);
disp(['   pgas,co2 = partial pressure of carbon dioxide gas (bar, true value, i.e. not normalized) = ', num2str(digesterout(end,49))]);
disp(['   pgas,total = total head space pressure of H2+CO2+CH4+H2O (bar, true value, i.e. not normalized) = ', num2str(digesterout(end,50))]);
disp(['   qgas = gas flow rate normalized to atmospheric pressure (m3/d) = ', num2str(digesterout(end,51))]);
disp('  Extra calculated outputs');
disp('  ------------------------');
disp(['   Produced hydrogen gas (kg H2/d) = ', num2str(digesterout(end,47)*P_atm*2/digesterout(end,50)/(R*T_op)*digesterout(end,51))]);
disp(['   Produced methane gas (kg CH4/d) = ', num2str(digesterout(end,48)*P_atm*16/digesterout(end,50)/(R*T_op)*digesterout(end,51))]);
disp(['   Produced carbon dioxide gas (kg CO2/d) = ', num2str(digesterout(end,49)*P_atm*44/digesterout(end,50)/(R*T_op)*digesterout(end,51))]);
disp(['   Energy content of methane gas (MJ/d) = ', num2str(digesterout(end,48)*P_atm*16/digesterout(end,50)/(R*T_op)*digesterout(end,51)*50.014)]);
disp(['   Energy content of methane gas (kWh/d) = ', num2str(digesterout(end,48)*P_atm*16/digesterout(end,50)/(R*T_op)*digesterout(end,51)*50.014/3.6)]);
disp(' ' )